==> realestate-supervise-common-1.0.0-20190527.033121-2-sources.jar: cn/gtmap/realestate/supervise/entity/BaQlrgx.java <==
package cn.gtmap.realestate.supervise.entity;

import cn.gtmap.realestate.supervise.core.reflect.*;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/17
 * @description ZTF_GY_QL_QLR_GX权利人（单位）和权利关系实体类
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_qlrgx"
)
public class BaQlrgx implements Serializable{

    @XmlAttribute
    @Id
    @id
    private String id;

    @XmlAttribute
    @Nullable
    private String bdcdyh;

    @XmlAttribute
    @Nullable
    private String zjzl;

    @XmlAttribute
    @Nullable
    private String zjhm;

    @XmlAttribute
    @Nullable
    private String qlrlx;

    @XmlAttribute
    @Nullable
    private String ysdm;

    @XmlAttribute
    @Nullable
    private String sxbh;

    @XmlAttribute
    @Nullable
    private String bdcqzh;

    @XmlAttribute
    @Nullable
    private String qlmj;

    @XmlAttribute
    @Nullable
    private String qlbl;

    @XmlAttribute
    @Nullable
    private String gyfs;

    @XmlAttribute
    @Nullable
    private String gyqk;

    @XmlAttribute
    @Nullable
    private String bz;

    @XmlAttribute
    @Nullable
    @qxdm
    private String qxdm;

    @Nullable
    private Date sjgxsj;

    @bwmc
    private String bwmc;

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }


    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getZjzl() {
        return zjzl;
    }

    public void setZjzl(String zjzl) {
        this.zjzl = zjzl;
    }

    public String getZjhm() {
        return zjhm;
    }

    public void setZjhm(String zjhm) {
        this.zjhm = zjhm;
    }

    public String getQlrlx() {
        return qlrlx;
    }

    public void setQlrlx(String qlrlx) {
        this.qlrlx = qlrlx;
    }

    public String getYsdm() {
        return ysdm;
    }

    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public String getSxbh() {
        return sxbh;
    }

    public void setSxbh(String sxbh) {
        this.sxbh = sxbh;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public String getQlmj() {
        return qlmj;
    }

    public void setQlmj(String qlmj) {
        this.qlmj = qlmj;
    }

    public String getQlbl() {
        return qlbl;
    }

    public void setQlbl(String qlbl) {
        this.qlbl = qlbl;
    }

    public String getGyfs() {
        return gyfs;
    }

    public void setGyfs(String gyfs) {
        this.gyfs = gyfs;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }
}

==> realestate-supervise-common-1.1.0-20230315.113754-29-sources.jar: cn/gtmap/realestate/supervise/entity/BaQlrgx.java <==
package cn.gtmap.realestate.supervise.entity;

import cn.gtmap.realestate.supervise.core.reflect.*;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/17
 * @description ZTF_GY_QL_QLR_GX权利人（单位）和权利关系实体类
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_qlrgx"
)
public class BaQlrgx implements Serializable{

    @XmlAttribute
    @Id
    @id
    private String id;

    @XmlAttribute
    @Nullable
    private String bdcdyh;

    @XmlAttribute
    @Nullable
    private String zjzl;

    @XmlAttribute
    @Nullable
    private String zjhm;

    @XmlAttribute
    @Nullable
    private String qlrlx;

    @XmlAttribute
    @Nullable
    private String ysdm;

    @XmlAttribute
    @Nullable
    private String sxbh;

    @XmlAttribute
    @Nullable
    private String bdcqzh;

    @XmlAttribute
    @Nullable
    private String qlmj;

    @XmlAttribute
    @Nullable
    private String qlbl;

    @XmlAttribute
    @Nullable
    private String gyfs;

    @XmlAttribute
    @Nullable
    private String gyqk;

    @XmlAttribute
    @Nullable
    private String bz;

    @XmlAttribute
    @Nullable
    @qxdm
    private String qxdm;

    @Nullable
    private Date sjgxsj;

    @bwmc
    private String bwmc;

    @XmlAttribute
    @Nullable
    private String dfgyfsdm;

    @XmlAttribute
    @Nullable
    private String dfgyfsmc;

    public String getDfgyfsdm() {
        return dfgyfsdm;
    }

    public void setDfgyfsdm(String dfgyfsdm) {
        this.dfgyfsdm = dfgyfsdm;
    }

    public String getDfgyfsmc() {
        return dfgyfsmc;
    }

    public void setDfgyfsmc(String dfgyfsmc) {
        this.dfgyfsmc = dfgyfsmc;
    }

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }


    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getZjzl() {
        return zjzl;
    }

    public void setZjzl(String zjzl) {
        this.zjzl = zjzl;
    }

    public String getZjhm() {
        return zjhm;
    }

    public void setZjhm(String zjhm) {
        this.zjhm = zjhm;
    }

    public String getQlrlx() {
        return qlrlx;
    }

    public void setQlrlx(String qlrlx) {
        this.qlrlx = qlrlx;
    }

    public String getYsdm() {
        return ysdm;
    }

    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public String getSxbh() {
        return sxbh;
    }

    public void setSxbh(String sxbh) {
        this.sxbh = sxbh;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public String getQlmj() {
        return qlmj;
    }

    public void setQlmj(String qlmj) {
        this.qlmj = qlmj;
    }

    public String getQlbl() {
        return qlbl;
    }

    public void setQlbl(String qlbl) {
        this.qlbl = qlbl;
    }

    public String getGyfs() {
        return gyfs;
    }

    public void setGyfs(String gyfs) {
        this.gyfs = gyfs;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }
}
